#include <stdio.h>
#include "iup.h"

Ihandle *InputCanvas;
Ihandle *mainDialog;

Ihandle *MenuReconhec;

void Dialogos(void)
{
 Ihandle *MenuLoadModeloItem = IupItem("Carregar Modelo", "load_modelo_cb");
 Ihandle *MenuLoadImagItem   = IupItem("Carregar Imagem", "load_imag_cb");
 Ihandle *MenuExitItem       = IupItem("Sair", "exit_cb");
 Ihandle *MenuArq            = IupMenu(MenuLoadModeloItem,
                                       MenuLoadImagItem,
                                       IupSeparator(),
                                       MenuExitItem,
                                       NULL);
 Ihandle *MenuReconhecimentoItem  = IupItem("Reconhecimento", "reconhecimento_cb");
 Ihandle *MenuMetodos             = IupMenu(MenuReconhecimentoItem,
                                            NULL);
 Ihandle *mainMenu = IupMenu(IupSubmenu("Arquivo", MenuArq),
                             IupSubmenu("Métodos", MenuMetodos),
                             NULL);
 InputCanvas = IupCanvas("redraw_in_cb");
 IupSetAttribute(InputCanvas, IUP_RASTERSIZE, "320x240");
 IupSetAttribute(InputCanvas, IUP_BORDER,    IUP_YES);
 mainDialog = IupDialog(IupHbox(InputCanvas, NULL));
 IupSetHandle("mainMenu", mainMenu);
 IupSetAttribute(mainDialog, IUP_RESIZE,    IUP_NO        );
 IupSetAttribute(mainDialog, IUP_MAXBOX,    IUP_NO        );
 IupSetAttribute(mainDialog, IUP_MENU,      "mainMenu"    );
 IupSetAttribute(mainDialog, IUP_BUTTON_CB, "button_cb"   );
 IupSetAttribute(mainDialog, IUP_CLOSE_CB,  "close_cb"    );
 IupSetAttribute(mainDialog, IUP_TITLE,     "Detecção de um campo de futebol");
}
